@@ -112,7 +112,7 @@ class GnocchiDriver(drivers.Driver):
             }
         elif storage_driver == "swift":
             storage_config = {
-                "swift_auth_url": "http://%s:%s/%s" % (
+                "swift_authurl": "http://%s:%s%s" % (
                     storage_parsed.hostname,
                     storage_parsed.port,
                     storage_parsed.path,
@@ -176,14 +176,12 @@ url = %s""" % (self.debug,
 
         c, _ = self._exec(["gnocchi-metricd", "--config-file=%s" % conffile],
                           wait_for_line="metrics wait to be processed")
-        self.addCleanup(self._kill, c)
 
         c, _ = self._exec(["gnocchi-statsd", "--config-file=%s" % conffile],
                           wait_for_line=("(Resource .* already exists"
                                          "|Created resource )"))
-        self.addCleanup(self._kill, c)
 
-        c, _ = self._exec([
+        args = [
             "uwsgi",
             "--http", "localhost:%d" % self.port,
             "--wsgi-file", spawn.find_executable("gnocchi-api"),
@@ -195,7 +193,14 @@ url = %s""" % (self.debug,
             "--chdir", self.tempdir,
             "--add-header", "Connection: close",
             "--pyargv", "--config-file=%s" % conffile,
-        ], wait_for_line="WSGI app 0 \(mountpoint=''\) ready")
+        ]
+
+        virtual_env = os.getenv("VIRTUAL_ENV")
+        if virtual_env is not None:
+            args.extend(["-H", virtual_env])
+
+        c, _ = self._exec(args,
+                          wait_for_line="WSGI app 0 \(mountpoint=''\) ready")
         self.addCleanup(self._kill, c)
 
         self.http_url = "http://localhost:%d" % self.port
