@@ -113,13 +113,18 @@ class SwiftDriver(drivers.Driver):
                      "sitecustomize.py"]:
             self.template(name, template_env, os.path.join(self.tempdir, name))
 
+        # swift requires data directory to exist: swift/commit/30fd4e
+        disk = 'fakedisk'
+        os.mkdir(os.path.join(self.tempdir, 'data'))
+        os.mkdir(os.path.join(self.tempdir, 'data', disk))
+
         self.useFixture(memcached.MemcachedDriver(self.memcached_port))
         for name in ["object", "container", "account"]:
             path = os.path.join(self.tempdir, "%s.builder" % name)
             port = getattr(self, "%s_port" % name)
             self._exec(["swift-ring-builder", path, "create", "10", "1", "1"])
             self._exec(["swift-ring-builder", path, "add",
-                        "r1z1-127.0.0.1:%s/fakedisk" % port, "1"])
+                        "r1z1-127.0.0.1:%s/%s" % (port, disk), "1"])
             self._exec(["swift-ring-builder", path, "rebalance"])
 
         # NOTE(sileht): to use sitecustomize.py that monkeypatch swift to be
@@ -130,7 +135,6 @@ class SwiftDriver(drivers.Driver):
             c, _ = self._exec(["swift-%s-server" % name,
                                os.path.join(self.tempdir, "%s.conf" % name)],
                               env=env, wait_for_line="started")
-            self.addCleanup(self._kill, c)
 
         # NOTE(sileht): we have no log, so ensure it work before returning
         # swiftclient retries 3 times before give up
